pkglts\.option\.version package
===============================

Submodules
----------

pkglts\.option\.version\.config module
--------------------------------------

.. automodule:: pkglts.option.version.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.version\.github\_versioning module
--------------------------------------------------

.. automodule:: pkglts.option.version.github_versioning
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.version\.handlers module
----------------------------------------

.. automodule:: pkglts.option.version.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.version
    :members:
    :undoc-members:
    :show-inheritance:
